var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const { RedisQueueClient } = require('../dist');
const Redis = require('ioredis');
function sleep(ms) {
    return new Promise(resolve => setTimeout(resolve, ms));
}
describe('RedisQueueClient', () => {
    let queue;
    let redis;
    beforeEach(() => __awaiter(this, void 0, void 0, function* () {
        redis = new Redis({
            host: 'localhost',
            port: 6379,
            lazyConnect: true,
            showFriendlyErrorStack: true,
        });
        yield redis.connect();
        queue = new RedisQueueClient({
            redis: redis,
            batchSize: 10,
            groupVisibilityTimeoutMs: 1000,
            pollingTimeoutMs: 1000,
            consumerCount: 1,
            redisKeyPrefix: `{redis-ordered-queue-test}`
        });
    }));
    afterEach(() => __awaiter(this, void 0, void 0, function* () {
        jest.clearAllMocks();
        // Cleanup Redis
        // await redis.send_command('FLUSHDB');
        redis.disconnect(false);
    }));
    describe('create', () => {
        const connectSpy = jest.spyOn(Redis.prototype, 'connect');
        it('should create a new instance', () => __awaiter(this, void 0, void 0, function* () {
            expect(queue).toBeInstanceOf(RedisQueueClient);
            expect(connectSpy).toHaveBeenCalled();
        }));
    });
    describe('enqueue', () => {
        const sendSpy = jest.spyOn(RedisQueueClient.prototype, 'send');
        it('should enqueue data', () => __awaiter(this, void 0, void 0, function* () {
            const data = { key: 'value' };
            yield expect(queue.send({ data, priority: 1, groupId: 'test-group' })).resolves.not.toThrowError();
            expect(sendSpy).toHaveBeenCalledTimes(1);
        }));
    });
    describe('start', () => {
        const handleMessageSpy = jest.fn();
        const startConsumersSpy = jest.spyOn(RedisQueueClient.prototype, 'startConsumers');
        afterEach(() => __awaiter(this, void 0, void 0, function* () {
            yield queue.stopConsumers();
        }));
        it('should receive messages', () => __awaiter(this, void 0, void 0, function* () {
            data = { key: 'value' };
            yield expect(queue.startConsumers({ handleMessage: handleMessageSpy })).resolves.not.toThrowError();
            yield queue.send({ data, priority: 1, groupId: 'test-group' });
            yield sleep(1000);
            expect(startConsumersSpy).toHaveBeenCalledTimes(1);
            expect(handleMessageSpy).toHaveBeenCalled();
        }));
    });
    describe('dispose', () => {
        const stopConsumersSpy = jest.spyOn(RedisQueueClient.prototype, 'stopConsumers');
        it('should stop listening and disconnect from Redis', () => __awaiter(this, void 0, void 0, function* () {
            yield expect(queue.stopConsumers()).resolves.not.toThrowError();
            expect(stopConsumersSpy).toHaveBeenCalled();
        }));
    });
});
//# sourceMappingURL=index.test.js.map